<img src="https://raw.githubusercontent.com/databio/yacman/master/docs/img/yacman_logo.svg?sanitize=true" alt="Refgenie" height="70"/><br>

[![Build Status](https://travis-ci.org/databio/yacman.svg?branch=master)](https://travis-ci.org/databio/yacman)

Yacman is a YAML configuration manager. It provides some convenience tools for dealing with YAML configuration files. 

Please see [this](docs/usage.ipynb) python notebook for features and usage instructions. 